<template>
  <!--日志基础配置-->
  <el-container>
    <el-main>
      <basic-container>
        <div style="margin: 0 0 10px 20px">
          <el-button v-if="form.delType == 0 && permissionList.saveBtn" icon="el-icon-check" size="small" type="primary"
                     @click="saveHandler">保存
          </el-button>
          <el-button v-if="form.delType != 0 && permissionList.delBtn" icon="el-icon-delete" size="small" type="danger"
                     @click="delHandler">删除
          </el-button>
        </div>
        <avue-form ref="form" v-model="form" :option="formOption"></avue-form>
        <div class="tip">
          <div style="color: #D40000;margin-left: 0;">日志基础配置说明：</div>
          <div>1、日志删除包含手动删除和自动删除。</div>
          <div>2、自动删除会根据日志的保存期限来进行日志删除。</div>
          <div>3、手动删除根据选定的时间来进行日志删除。</div>
        </div>
      </basic-container>
    </el-main>

  </el-container>
</template>

<script>
import {getPeroid, savePeriod, deleteLog} from "@/api/system/log/logBasic";
import {mapGetters} from "vuex";

export default {
  name: "basicConf",
  data: function () {
    return {
      form: {
        period: '',
      },
      periodData: [],
      formOption: {
        submitBtn: false,
        emptyBtn: false,
        column: [{
          label: '日志删除',
          prop: 'delType',
          span: 24,
          labelWidth: 120,
          type: 'radio',
          value: 0,
          dicData: [
            {label: '自动删除', value: 0},
            {label: '手动删除', value: 1},
          ]
        }, {
          label: '保存日期',
          prop: 'period',
          type: 'select',
          labelWidth: 120,
          dicData: this.periodData,
          props: {
            label: 'value',
            value: 'code'
          },
          rules: [{
            required: true,
            message: "请选择保存日期",
            trigger: "blur"
          }]
        }, {
          label: '请选择日期',
          prop: 'deleteDate',
          type: 'date',
          valueFormat: 'yyyy-MM-dd',
          labelWidth: 120,
          display: false,
          rules: [{
            required: true,
            message: "请选择日期",
            trigger: "blur"
          }]
        }]
      },
    }
  },
  computed: {
    ...mapGetters(["permission"]),
    permissionList() {
      return {
        saveBtn: this.vaildData(this.permission[this.$route.query.id].save, false),
        delBtn: this.vaildData(this.permission[this.$route.query.id].DELETE, false),
      };
    },
  },
  created() {
    this.getPeroid();
  },
  watch: {
    'form.delType': {
      handler(newval) {
        if (newval == 0) {
          this.formOption.column[1].display = true;
          this.formOption.column[2].display = false;
        } else {
          this.formOption.column[1].display = false;
          this.formOption.column[2].display = true;
        }
      }
    },
  },
  methods: {
    getPeroid: function () {
      getPeroid().then(res => {
        this.$refs.form.updateDic('period', res.data.data);
        this.periodData = res.data.data;
        this.form.period = res.data.data.filter(item => {
          return item.choose
        })[0].code
      }).catch(error => {
      })
    },
    saveHandler: function () {
      savePeriod({'period': this.form.period}).then(res => {
        if (res.data.success) {
          this.$message.success('保存成功')
        }
      });
    },
    delHandler() {
      this.$refs.form.validate((valid, done) => {
        if (valid) {
          deleteLog({'deleteDate': this.form.deleteDate}).then(res => {
            if (res.data.success) {
              this.$message.success('删除成功')
            }
          });
          done()
        }
      })
    },
  }
}
</script>

<style scoped>
.tip {
  font-size: 12px;
  line-height: 24px;
  color: #909399;
  margin: 0 0 10px 20px;
}

.tip div {
  margin-left: 30px;
}
</style>
